==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-russian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," ");
define("_CATEGORY","");
define("_CATEGORIES","");
define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_LINKTITLE","  ");
define("_HITS","");
define("_THEREARE","");
define("_NOMATCHES","     ");
define("_SCOMMENTS","");
define("_DESCRIPTION","");
define("_DATE","");
define("_TO","");
define("_ADDLINK"," ");
define("_NEW","");
define("_POPULAR","");
define("_TOPRATED","-");
define("_RANDOM","");
define("_LINKSMAIN"," ");
define("_LINKCOMMENTS","");
define("_ADDITIONALDET"," ");
define("_EDITORREVIEW"," ");
define("_REPORTBROKEN","   ");
define("_LINKSMAINCAT","");
define("_AND","");
define("_INDB","   ");
define("_ADDALINK","  ");
define("_INSTRUCTIONS","");
define("_SUBMITONCE","      .");
define("_POSTPENDING","  .");
define("_USERANDIP","   IP ,     .");
define("_PAGETITLE"," ");
define("_PAGEURL"," ");
define("_YOUREMAIL"," Email");
define("_LDESCRIPTION",": (  255 )");
define("_ADDURL","");
define("_LINKSNOTUSER1","          .");
define("_LINKSNOTUSER2","      .");
define("_LINKSNOTUSER3","   -    .");
define("_LINKSNOTUSER4","Why do we require registration for access to certain features?");
define("_LINKSNOTUSER5","So we can offer you only the highest quality content,");
define("_LINKSNOTUSER6","each item is individually reviewed and approved by our staff.");
define("_LINKSNOTUSER7","We hope to offer you only valuable information.");
define("_LINKSNOTUSER8","<a href=\"user.php\">Register for an Account</a>");
define("_LINKALREADYEXT","ERROR:      !");
define("_LINKNOTITLE","ERROR:      !");
define("_LINKNOURL","ERROR:       !");
define("_LINKNODESC","ERROR:       !");
define("_LINKRECEIVED","   . !");
define("_EMAILWHENADD","       .");
define("_CHECKFORIT","      .     .");
define("_NEWLINKS"," ");
define("_TOTALNEWLINKS","  ");
define("_LASTWEEK","  ");
define("_LAST30DAYS","  30 ");
define("_1WEEK","1 ");
define("_2WEEKS","2 ");
define("_30DAYS","30 ");
define("_SHOW","");
define("_TOTALFORLAST","   ");
define("_DAYS","");
define("_ADDEDON"," ");
define("_RATING","");
define("_RATESITE","  ");
define("_DETAILS","");
define("_BESTRATED","  - ");
define("_OF","of");
define("_TRATEDLINKS","total rated links");
define("_TVOTESREQ"," ");
define("_SHOWTOP"," To");
define("_MOSTPOPULAR","  - Top");
define("_OFALL"," ");
define("_SORTLINKSBY","  ");
define("_SITESSORTED","  ");
define("_POPULARITY","");
define("_SELECTPAGE"," ");
define("_MAIN","");
define("_NEWTODAY"," ");
define("_NEWLAST3DAYS","   3 ");
define("_NEWTHISWEEK","   ");
define("_CATNEWTODAY","      ");
define("_CATLAST3DAYS","        3 ");
define("_CATTHISWEEK","        ");
define("_POPULARITY1"," (   )");
define("_POPULARITY2"," (Most to Least Hits)");
define("_TITLEAZ"," (A  Z)");
define("_TITLEZA"," (Z  A)");
define("_DATE1"," (   )");
define("_DATE2"," (  )");
define("_RATING1"," (    )");
define("_RATING2","Rating (   )");
define("_SEARCHRESULTS4","  ");
define("_USUBCATEGORIES","");
define("_LINKS","");
define("_TRY2SEARCH"," ");
define("_INOTHERSENGINES","   ");
define("_EDITORIAL","Editorial");
define("_LINKPROFILE"," ");
define("_EDITORIALBY","Editorial by");
define("_NOEDITORIAL","No editorial is currently available for this website.");
define("_VISITTHISSITE","  ");
define("_RATETHISSITE","  ");
define("_ISTHISYOURSITE","  ?");
define("_ALLOWTORATE","       !");
define("_LINKRATINGDET"," ");
define("_OVERALLRATING","Overall Rating");
define("_TOTALOF"," ");
define("_USER","");
define("_USERAVGRATING"," User's Average Rating");
define("_NUMRATINGS","# ");
define("_EDITTHISLINK"," ");
define("_REGISTEREDUSERS"," ");
define("_NUMBEROFRATINGS"," ");
define("_NOREGUSERSVOTES","   ");
define("_BREAKDOWNBYVAL","    ");
define("_LTOTALVOTES","total votes");
define("_LINKRATING"," ");
define("_HIGHRATING"," ");
define("_LOWRATING"," ");
define("_NUMOFCOMMENTS"," ");
define("_WEIGHNOTE","* Note: This website weighs Registered vs. Unregistered users ratings");
define("_NOUNREGUSERSVOTES","No Unregistered User Votes");
define("_WEIGHOUTNOTE","* Note: This website weighs Registered vs. Outside voters ratings");
define("_NOOUTSIDEVOTES","No Outside Votes");
define("_OUTSIDEVOTERS","Outside Voters");
define("_UNREGISTEREDUSERS","  ");
define("_PROMOTEYOURSITE","  ");
define("_PROMOTE01","Maybe you can be interested in several of the remote 'Rate a Website' options we have available. These allow you to place an image (or even a rating form) on your web site in order to increase the number of votes your website receive. Please choose from one of the options listed below:");
define("_TEXTLINK"," ");
define("_PROMOTE02","One way to link to the rating form is through a simple text link:");
define("_HTMLCODE1"," HTML    :");
define("_THENUMBER","");
define("_IDREFER","in the HTML source references your site's ID number in $sitename database. Be sure this number is present.");
define("_BUTTONLINK","Button Link");
define("_PROMOTE03","If you're looking for a little more than a basic text link, you may wish to use a small button link:");
define("_RATEIT","Rate this Site!");
define("_HTMLCODE2","The source code for the above button is:");
define("_REMOTEFORM","Remote Rating Form");
define("_PROMOTE04","If you cheat on this, we'll remove your link. Having said that, here is what the current remote rating form looks like.");
define("_VOTE4THISSITE","Vote for this Site!");
define("_LINKVOTE","!");
define("_HTMLCODE3","Using this form will allow users to rate your website directly from your site and the rating will be recorded here. The above form is disabled, but the following source code will work if you simply cut and paste it into your web page. The source code is shown below:");
define("_PROMOTE05","Thanks! and good luck with your ratings!");
define("_STAFF","");
define("_THANKSBROKEN","Thank you for helping to maintain this directory's integrity.");
define("_THANKSFORINFO","  .");
define("_LOOKTOREQUEST","We'll look into your request shortly.");
define("_ONLYREGUSERSMODIFY","Only registered users can suggest links modifications. Please <a href=\"user.php\">register or login</a>.");
define("_REQUESTLINKMOD","Request Link Modification");
define("_LINKID","ID ");
define("_SENDREQUEST","Send Request");
define("_THANKSTOTAKETIME","Thank you for taking the time to rate a site here at");
define("_LETSDECIDE","Input from users such as yourself will help other visitors better decide which links to click on.");
define("_RETURNTO"," ");
define("_RATENOTE1","      .");
define("_RATENOTE2"," 1 - 10,  1   10 .");
define("_RATENOTE3","  .      1   10     ");
define("_RATENOTE4","   <a href=\"links.php?op=TopRated\">Top   </a>.");
define("_RATENOTE5","    .");
define("_YOUAREREGGED","  .    ");
define("_FEELFREE2ADD","  .");
define("_YOUARENOTREGGED","         .");
define("_IFYOUWEREREG","       .");
define("_WEBLINKS"," ");
define("_TITLE","");
define("_MODIFY","");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-russian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," ");
define("_CATEGORY","");
define("_CATEGORIES","");
define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_LINKTITLE","  ");
define("_HITS","");
define("_THEREARE","");
define("_NOMATCHES","     ");
define("_SCOMMENTS","");
define("_DESCRIPTION","");
define("_DATE","");
define("_TO","");
define("_ADDLINK"," ");
define("_NEW","");
define("_POPULAR","");
define("_TOPRATED","-");
define("_RANDOM","");
define("_LINKSMAIN"," ");
define("_LINKCOMMENTS","");
define("_ADDITIONALDET"," ");
define("_EDITORREVIEW"," ");
define("_REPORTBROKEN","   ");
define("_LINKSMAINCAT","");
define("_AND","");
define("_INDB","   ");
define("_ADDALINK","  ");
define("_INSTRUCTIONS","");
define("_SUBMITONCE","      .");
define("_POSTPENDING","  .");
define("_USERANDIP","   IP ,     .");
define("_PAGETITLE"," ");
define("_PAGEURL"," ");
define("_YOUREMAIL"," Email");
define("_LDESCRIPTION",": (  255 )");
define("_ADDURL","");
define("_LINKSNOTUSER1","          .");
define("_LINKSNOTUSER2","      .");
define("_LINKSNOTUSER3","   -    .");
define("_LINKSNOTUSER4","Why do we require registration for access to certain features?");
define("_LINKSNOTUSER5","So we can offer you only the highest quality content,");
define("_LINKSNOTUSER6","each item is individually reviewed and approved by our staff.");
define("_LINKSNOTUSER7","We hope to offer you only valuable information.");
define("_LINKSNOTUSER8","<a href=\"user.php\">Register for an Account</a>");
define("_LINKALREADYEXT","ERROR:      !");
define("_LINKNOTITLE","ERROR:      !");
define("_LINKNOURL","ERROR:       !");
define("_LINKNODESC","ERROR:       !");
define("_LINKRECEIVED","   . !");
define("_EMAILWHENADD","       .");
define("_CHECKFORIT","      .     .");
define("_NEWLINKS"," ");
define("_TOTALNEWLINKS","  ");
define("_LASTWEEK","  ");
define("_LAST30DAYS","  30 ");
define("_1WEEK","1 ");
define("_2WEEKS","2 ");
define("_30DAYS","30 ");
define("_SHOW","");
define("_TOTALFORLAST","   ");
define("_DAYS","");
define("_ADDEDON"," ");
define("_RATING","");
define("_RATESITE","  ");
define("_DETAILS","");
define("_BESTRATED","  - ");
define("_OF","of");
define("_TRATEDLINKS","total rated links");
define("_TVOTESREQ"," ");
define("_SHOWTOP"," To");
define("_MOSTPOPULAR","  - Top");
define("_OFALL"," ");
define("_SORTLINKSBY","  ");
define("_SITESSORTED","  ");
define("_POPULARITY","");
define("_SELECTPAGE"," ");
define("_MAIN","");
define("_NEWTODAY"," ");
define("_NEWLAST3DAYS","   3 ");
define("_NEWTHISWEEK","   ");
define("_CATNEWTODAY","      ");
define("_CATLAST3DAYS","        3 ");
define("_CATTHISWEEK","        ");
define("_POPULARITY1"," (   )");
define("_POPULARITY2"," (Most to Least Hits)");
define("_TITLEAZ"," (A  Z)");
define("_TITLEZA"," (Z  A)");
define("_DATE1"," (   )");
define("_DATE2"," (  )");
define("_RATING1"," (    )");
define("_RATING2","Rating (   )");
define("_SEARCHRESULTS4","  ");
define("_USUBCATEGORIES","");
define("_LINKS","");
define("_TRY2SEARCH"," ");
define("_INOTHERSENGINES","   ");
define("_EDITORIAL","Editorial");
define("_LINKPROFILE"," ");
define("_EDITORIALBY","Editorial by");
define("_NOEDITORIAL","No editorial is currently available for this website.");
define("_VISITTHISSITE","  ");
define("_RATETHISSITE","  ");
define("_ISTHISYOURSITE","  ?");
define("_ALLOWTORATE","       !");
define("_LINKRATINGDET"," ");
define("_OVERALLRATING","Overall Rating");
define("_TOTALOF"," ");
define("_USER","");
define("_USERAVGRATING"," User's Average Rating");
define("_NUMRATINGS","# ");
define("_EDITTHISLINK"," ");
define("_REGISTEREDUSERS"," ");
define("_NUMBEROFRATINGS"," ");
define("_NOREGUSERSVOTES","   ");
define("_BREAKDOWNBYVAL","    ");
define("_LTOTALVOTES","total votes");
define("_LINKRATING"," ");
define("_HIGHRATING"," ");
define("_LOWRATING"," ");
define("_NUMOFCOMMENTS"," ");
define("_WEIGHNOTE","* Note: This website weighs Registered vs. Unregistered users ratings");
define("_NOUNREGUSERSVOTES","No Unregistered User Votes");
define("_WEIGHOUTNOTE","* Note: This website weighs Registered vs. Outside voters ratings");
define("_NOOUTSIDEVOTES","No Outside Votes");
define("_OUTSIDEVOTERS","Outside Voters");
define("_UNREGISTEREDUSERS","  ");
define("_PROMOTEYOURSITE","  ");
define("_PROMOTE01","Maybe you can be interested in several of the remote 'Rate a Website' options we have available. These allow you to place an image (or even a rating form) on your web site in order to increase the number of votes your website receive. Please choose from one of the options listed below:");
define("_TEXTLINK"," ");
define("_PROMOTE02","One way to link to the rating form is through a simple text link:");
define("_HTMLCODE1"," HTML    :");
define("_THENUMBER","");
define("_IDREFER","in the HTML source references your site's ID number in $sitename database. Be sure this number is present.");
define("_BUTTONLINK","Button Link");
define("_PROMOTE03","If you're looking for a little more than a basic text link, you may wish to use a small button link:");
define("_RATEIT","Rate this Site!");
define("_HTMLCODE2","The source code for the above button is:");
define("_REMOTEFORM","Remote Rating Form");
define("_PROMOTE04","If you cheat on this, we'll remove your link. Having said that, here is what the current remote rating form looks like.");
define("_VOTE4THISSITE","Vote for this Site!");
define("_LINKVOTE","!");
define("_HTMLCODE3","Using this form will allow users to rate your website directly from your site and the rating will be recorded here. The above form is disabled, but the following source code will work if you simply cut and paste it into your web page. The source code is shown below:");
define("_PROMOTE05","Thanks! and good luck with your ratings!");
define("_STAFF","");
define("_THANKSBROKEN","Thank you for helping to maintain this directory's integrity.");
define("_THANKSFORINFO","  .");
define("_LOOKTOREQUEST","We'll look into your request shortly.");
define("_ONLYREGUSERSMODIFY","Only registered users can suggest links modifications. Please <a href=\"user.php\">register or login</a>.");
define("_REQUESTLINKMOD","Request Link Modification");
define("_LINKID","ID ");
define("_SENDREQUEST","Send Request");
define("_THANKSTOTAKETIME","Thank you for taking the time to rate a site here at");
define("_LETSDECIDE","Input from users such as yourself will help other visitors better decide which links to click on.");
define("_RETURNTO"," ");
define("_RATENOTE1","      .");
define("_RATENOTE2"," 1 - 10,  1   10 .");
define("_RATENOTE3","  .      1   10     ");
define("_RATENOTE4","   <a href=\"links.php?op=TopRated\">Top   </a>.");
define("_RATENOTE5","    .");
define("_YOUAREREGGED","  .    ");
define("_FEELFREE2ADD","  .");
define("_YOUARENOTREGGED","         .");
define("_IFYOUWEREREG","       .");
define("_WEBLINKS"," ");
define("_TITLE","");
define("_MODIFY","");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
